@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy.pm $
-#     $Date: 2008-04-13 20:15:13 -0500 (Sun, 13 Apr 2008) $
+#     $Date: 2008-05-17 00:26:31 -0500 (Sat, 17 May 2008) $
 #   $Author: clonezone $
-# $Revision: 2233 $
+# $Revision: 2340 $
 ##############################################################################
 
 package Perl::Critic::Policy;
@@ -13,6 +13,7 @@ use warnings;
 use English qw< -no_match_vars >;
 use Readonly;
 
+use File::Spec ();
 use String::Format qw< stringf >;
 
 use overload ( q<""> => 'to_string', cmp => '_compare' );
@@ -29,6 +30,10 @@ use Perl::Critic::Utils qw<
     severity_to_number
 >;
 use Perl::Critic::Utils::DataConversion qw< dor >;
+use Perl::Critic::Utils::POD qw<
+    get_module_abstract_for_module
+    get_raw_module_abstract_for_module
+>;
 use Perl::Critic::Exception::AggregateConfiguration;
 use Perl::Critic::Exception::Configuration;
 use Perl::Critic::Exception::Configuration::Option::Policy::ExtraParameter;
@@ -41,7 +46,7 @@ use Perl::Critic::Violation qw<>;
 
 use Exception::Class;   # this must come after "use P::C::Exception::*"
 
-our $VERSION = '1.083_001';
+our $VERSION = '1.083_002';
 
 #-----------------------------------------------------------------------------
 
@@ -352,6 +357,22 @@ sub default_themes {
 
 #-----------------------------------------------------------------------------
 
+sub get_abstract {
+    my ($self) = @_;
+
+    return get_module_abstract_for_module( ref $self );
+}
+
+#-----------------------------------------------------------------------------
+
+sub get_raw_abstract {
+    my ($self) = @_;
+
+    return get_raw_module_abstract_for_module( ref $self );
+}
+
+#-----------------------------------------------------------------------------
+
 sub parameter_metadata_available {
     my ($self) = @_;
 
@@ -428,16 +449,17 @@ sub to_string {
 
     # Wrap the more expensive ones in sub{} to postpone evaluation
     my %fspec = (
-         'O' => sub { $self->_format_parameters(@_) },
-         'U' => sub { $self->_format_lack_of_parameter_metadata(@_) },
          'P' => sub { $self->get_long_name() },
          'p' => sub { $self->get_short_name() },
+         'a' => sub { dor($self->get_abstract(), $EMPTY) },
+         'O' => sub { $self->_format_parameters(@_) },
+         'U' => sub { $self->_format_lack_of_parameter_metadata(@_) },
+         'S' => sub { $self->default_severity() },
+         's' => sub { $self->get_severity() },
          'T' => sub { join $SPACE, $self->default_themes() },
          't' => sub { join $SPACE, $self->get_themes() },
          'V' => sub { dor( $self->default_maximum_violations_per_document(), $NO_LIMIT ) },
          'v' => sub { dor( $self->get_maximum_violations_per_document(), $NO_LIMIT ) },
-         'S' => sub { $self->default_severity() },
-         's' => sub { $self->get_severity() },
     );
     return stringf($FORMAT, %fspec);
 }
@@ -471,6 +493,15 @@ sub _format_lack_of_parameter_metadata {
         'Cannot programmatically discover what parameters this policy takes.';
 }
 
+sub _get_source_file {
+    my ($self) = @_;
+
+    my $relative_path =
+        File::Spec->catfile( split m/::/xms, ref $self ) . '.pm';
+
+    return $INC{$relative_path};
+}
+
 
 #-----------------------------------------------------------------------------
 # Apparently, some perls do not implicitly stringify overloading
@@ -678,6 +709,19 @@ Appends additional themes to this Policy.  Any existing themes are
 preserved.  Duplicate themes will be removed.
 
 
+=item C< get_abstract() >
+
+Retrieve the abstract for this policy (the part of the NAME section of
+the POD after the module name), if it is available.
+
+
+=item C< get_raw_abstract() >
+
+Retrieve the abstract for this policy (the part of the NAME section of
+the POD after the module name), if it is available, in the unparsed
+form.
+
+
 =item C< parameter_metadata_available() >
 
 Returns whether information about the parameters is available.
@@ -744,6 +788,21 @@ capabilities, look at L<String::Format>. Valid escape characters are:
 
 =over
 
+=item C<%P>
+
+Name of the Policy module.
+
+
+=item C<%p>
+
+Name of the Policy without the C<Perl::Critic::Policy::> prefix.
+
+
+=item C<%a>
+
+The policy abstract.
+
+
 =item C<%O>
 
 List of supported policy parameters.  Takes an option of a format
@@ -762,26 +821,6 @@ option is interpolated in order to expand the standard escape
 sequences (C<\n>, C<\t>, etc.).
 
 
-=item C<%P>
-
-Name of the Policy module.
-
-
-=item C<%p>
-
-Name of the Policy without the C<Perl::Critic::Policy::> prefix.
-
-
-=item C<%V>
-
-The default maximum number of violations per document of the policy.
-
-
-=item C<%V>
-
-The current maximum number of violations per document of the policy.
-
-
 =item C<%S>
 
 The default severity level of the policy.
@@ -802,6 +841,16 @@ The default themes for the policy.
 The current themes for the policy.
 
 
+=item C<%V>
+
+The default maximum number of violations per document of the policy.
+
+
+=item C<%v>
+
+The current maximum number of violations per document of the policy.
+
+
 =back
 
 
