@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/CodeLayout/ProhibitTrailingWhitespace.pm $
-#     $Date: 2008-04-13 20:15:13 -0500 (Sun, 13 Apr 2008) $
+#     $Date: 2008-05-17 00:26:31 -0500 (Sat, 17 May 2008) $
 #   $Author: clonezone $
-# $Revision: 2233 $
+# $Revision: 2340 $
 ##############################################################################
 
 package Perl::Critic::Policy::CodeLayout::ProhibitTrailingWhitespace;
@@ -19,7 +19,7 @@ use Perl::Critic::Utils qw{ :characters :severities };
 
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.083_001';
+our $VERSION = '1.083_002';
 
 #-----------------------------------------------------------------------------
 
@@ -102,7 +102,12 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::CodeLayout::ProhibitTrailingWhitespace
+Perl::Critic::Policy::CodeLayout::ProhibitTrailingWhitespace - Don't use whitespace at the end of lines.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic> distribution.
+
 
 =head1 DESCRIPTION
 
@@ -112,6 +117,12 @@ code, their editors may automatically strip out trailing whitespace,
 causing spurious differences between different versions of the same
 file (i.e. code in a source control system).
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 AUTHOR
 
 Elliot Shank C<< <perl@galumph.com> >>
