@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/ErrorHandling/RequireCarping.pm $
-#     $Date: 2008-04-13 20:15:13 -0500 (Sun, 13 Apr 2008) $
+#     $Date: 2008-05-17 00:26:31 -0500 (Sat, 17 May 2008) $
 #   $Author: clonezone $
-# $Revision: 2233 $
+# $Revision: 2340 $
 ##############################################################################
 
 package Perl::Critic::Policy::ErrorHandling::RequireCarping;
@@ -17,7 +17,7 @@ use Perl::Critic::Utils qw{
 use Perl::Critic::Utils::PPI qw{ is_ppi_expression_or_generic_statement };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.083_001';
+our $VERSION = '1.083_002';
 
 #-----------------------------------------------------------------------------
 
@@ -353,7 +353,12 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ErrorHandling::RequireCarping
+Perl::Critic::Policy::ErrorHandling::RequireCarping - Use functions from L<Carp> instead of C<warn> or C<die>.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic> distribution.
+
 
 =head1 DESCRIPTION
 
@@ -386,6 +391,8 @@ none of the L<Carp> functions are necessary.
     die $message if $no_time;             #not ok, not obvious
 
 
+=head1 CONFIGURATION
+
 If you give this policy an C<allow_messages_ending_with_newlines>
 option in your F<.perlcriticrc> with a false value, then this policy
 will disallow all uses of C<die> and C<warn>.
@@ -393,6 +400,7 @@ will disallow all uses of C<die> and C<warn>.
     [ErrorHandling::RequireCarping]
     allow_messages_ending_with_newlines = 0
 
+
 =head1 SEE ALSO
 
 L<Carp::Always>
