@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/TestUtils.pm $
-#     $Date: 2008-04-13 20:15:13 -0500 (Sun, 13 Apr 2008) $
+#     $Date: 2008-05-17 00:26:31 -0500 (Sat, 17 May 2008) $
 #   $Author: clonezone $
-# $Revision: 2233 $
+# $Revision: 2340 $
 ##############################################################################
 
 package Perl::Critic::TestUtils;
@@ -27,7 +27,7 @@ use Perl::Critic::Exception::Fatal::Internal qw{ &throw_internal };
 use Perl::Critic::Utils qw{ :severities :data_conversion policy_long_name };
 use Perl::Critic::PolicyFactory (-test => 1);
 
-our $VERSION = '1.083_001';
+our $VERSION = '1.083_002';
 
 Readonly::Array our @EXPORT_OK => qw(
     pcritique pcritique_with_violations
@@ -291,9 +291,11 @@ sub bundled_policy_names {
 }
 
 sub names_of_policies_willing_to_work {
+    my %configuration = @_;
+
     my @policies_willing_to_work =
         Perl::Critic::Config
-            ->new( -severity => $SEVERITY_LOWEST )
+            ->new( %configuration )
             ->policies();
 
     return map { ref $_ } @policies_willing_to_work;
@@ -424,10 +426,10 @@ Returns a list of Policy packages that come bundled with this package.  This
 functions by searching F<MANIFEST> for F<lib/Perl/Critic/Policy/*.pm> and
 converts the results to package names.
 
-=item names_of_policies_willing_to_work()
+=item names_of_policies_willing_to_work( %configuration )
 
 Returns a list of the packages of policies that are willing to function on
-the current system.
+the current system using the specified configuration.
 
 =back
 
