@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/t/tlib/Perl/Critic/TestUtilitiesWithMinimalDependencies.pm $
-#     $Date: 2008-04-13 20:15:13 -0500 (Sun, 13 Apr 2008) $
+#     $Date: 2008-05-17 00:26:31 -0500 (Sat, 17 May 2008) $
 #   $Author: clonezone $
-# $Revision: 2233 $
+# $Revision: 2340 $
 ##############################################################################
 
 package Perl::Critic::TestUtilitiesWithMinimalDependencies;
@@ -14,31 +14,13 @@ use warnings;
 
 use base 'Exporter';
 
-our $VERSION = '1.083_001';
+our $VERSION = '1.083_002';
 our @EXPORT_OK = qw(
-    should_skip_author_tests
-    get_author_test_skip_message
     get_skip_all_tests_tap
 );
 
 #-----------------------------------------------------------------------------
 
-# Note: this code is duplicated in lib/Perl/Critic/TestUtils.pm.
-# If you change this here, make sure to change it there.
-
-sub should_skip_author_tests {
-    return not $ENV{TEST_AUTHOR_PERL_CRITIC};
-}
-
-#-----------------------------------------------------------------------------
-
-sub get_author_test_skip_message {
-    ## no critic (RequireInterpolation);
-    return 'Author test.  Set $ENV{TEST_AUTHOR_PERL_CRITIC} to a true value to run.';
-}
-
-#-----------------------------------------------------------------------------
-
 sub get_skip_all_tests_tap {
     return '1..0 # Skip ';
 }
@@ -60,21 +42,13 @@ Perl::Critic::TestUtilitiesWithMinimalDependencies - Testing functions that only
 =head1 SYNOPSIS
 
   use Perl::Critic::TestUtilitiesWithMinimalDependencies qw{
-      should_skip_author_tests
-      get_author_test_skip_message
       get_skip_all_tests_tap
   };
 
-  if ( should_skip_author_tests() ) {
-      print get_skip_all_tests_tap(), get_author_test_skip_message(), "\n";
-      exit 0;
-  }
-
-
   use Test::More;
 
-  if (should_skip_author_tests()) {
-      plan skip_all => get_author_test_skip_message();
+  if ($should_not_run) {
+      plan skip_all => 'Hey!  I shouldn't be run!';
   }
 
 =head1 DESCRIPTION
@@ -88,18 +62,6 @@ that need to hide the presence of other modules before starting.
 
 =over
 
-=item C< should_skip_author_tests() >
-
-Answers whether author tests should run.
-
-
-=item C< get_author_test_skip_message() >
-
-Returns a string containing the message that should be emitted when a
-test is skipped due to it being an author test when author tests are
-not enabled.
-
-
 =item C< get_skip_all_tests_tap() >
 
 Returns a string representing the TAP (Test Anything Protocol) output
@@ -107,6 +69,9 @@ for skipping an entire file.  This is useful if you don't want to load
 any Test::* modules.
 
 
+=back
+
+
 =head1 AUTHOR
 
 Elliot Shank <perl@cpan.org>
